@@ -1,3 +1,3 @@
 from zodipy.zodi import Zodi
 
-__all__ = ["Zodi"]
\ No newline at end of file
+__all__ = ("Zodi",)
