@@ -4,6 +4,9 @@ from typing import Iterable, Dict, Union, Tuple
 from zodipy._components import BaseComponent, Cloud, Band, Ring, Feature
 from zodipy._emissivities import Emissivities
 
+ModelParameterType = Dict[str, Dict[str, float]]
+EmissivitiesType = Dict[str, Union[Tuple[float], Dict[str, Tuple[float]]]]
+
 
 @dataclass
 class InterplanetaryDustModel:
@@ -20,25 +23,25 @@ class ModelFactory:
         self._models = {}
 
     def register_model(
-        self, 
-        name: str, 
-        components: Iterable[str], 
-        parameters: Dict[str, Dict[str, float]],
-        emissivities: Dict[str, Union[Tuple[float], Dict[str, Tuple[float]]]]
+        self,
+        name: str,
+        components: Iterable[str],
+        parameters: ModelParameterType,
+        emissivities: EmissivitiesType,
     ) -> None:
         """Initializes and stores a model."""
 
         model = _init_model(components, parameters, emissivities)
         self._models[name] = model
 
-    def get_model(self, name: str) -> InterplanetaryDustModel: 
+    def get_model(self, name: str) -> InterplanetaryDustModel:
         """Returns a registered model."""
-        
+
         model = self._models.get(name)
         if model is None:
             raise ValueError(
-                f'model {name} is not registered. Available models are '
-                f'{list(self._models.keys())}'
+                f"model {name} is not registered. Available models are "
+                f"{list(self._models.keys())}"
             )
 
         return model
@@ -47,19 +50,18 @@ class ModelFactory:
 def _init_model(components, parameters, emissivities):
     initialized_components = {}
     for comp in components:
-        if comp.startswith('cloud'):
+        if comp.startswith("cloud"):
             comp_type = Cloud
-        elif comp.startswith('band'):
+        elif comp.startswith("band"):
             comp_type = Band
-        elif comp.startswith('ring'):
+        elif comp.startswith("ring"):
             comp_type = Ring
-        elif comp.startswith('feature'):
+        elif comp.startswith("feature"):
             comp_type = Feature
         initialized_components[comp] = comp_type(**parameters[comp])
-        
+
     emissivities = Emissivities(**emissivities)
 
     return InterplanetaryDustModel(
-        components=initialized_components,
-        emissivities=emissivities
-    )
\ No newline at end of file
+        components=initialized_components, emissivities=emissivities
+    )
